@@ -1,6 +1,7 @@
 from arkitekt.apps import Arkitekt
 from fakts.grants.remote.device_code import DeviceCodeGrant
 from fakts.fakts import Fakts
+from fakts.grants.remote.static import StaticGrant
 from fakts.grants import CacheGrant
 from herre.grants import CacheGrant as HerreCacheGrant
 from herre.grants.oauth2.refresh import RefreshGrant
@@ -70,6 +71,63 @@ token: str = None) -> Arkitekt:
         ),
     )
 
+def port(
+    identifier: str, version: str = "latest", url: str = "http://localhost:8000/f/",  log_level: str = "ERROR",
+token: str = None) -> Arkitekt:
+    """Easy port creation
+
+    A simple way to create an Arkitekt app with a device code grant
+    it will cache the configuration in a file called `identifier`_token.json
+    and the cache in a file called `identifier`_cache.json
+
+    Args:
+        identifier (str): The apps identifier
+        version (str, optional): The apps verion. Defaults to "latest".
+        url (_type_, optional): The app configuration url. Defaults to "http://localhost:8000/f/".
+        headless (bool, optional): Do not open a browser window. Defaults to False.
+        allow_sync_in_async (bool, optional): Should we allow the creation of a sync interface in an async loop (necessary for a sync interface in jupyter). Defaults to True.
+
+    Returns:
+        Arkitekt: _description_
+    """
+
+    url = os.getenv("FAKTS_URL", url)
+    token = os.getenv("FAKTS_TOKEN", token)
+
+    if not token:
+        raise ValueError("You must provide a token")
+
+    if not url:
+        raise ValueError("You must provide a url")
+
+    create_arkitekt_folder(with_cache=True)
+
+    try:
+        from rich.logging import RichHandler
+
+        logging.basicConfig(level=log_level, handlers=[RichHandler()])
+    except ImportError:
+        logging.basicConfig(level=log_level)
+
+
+    return Arkitekt(
+        title=identifier,
+        fakts=Fakts(
+            grant=CacheGrant(
+                cache_file=f".arkitekt/cache/{identifier}-{version}_cache.json",
+                hash=f"{identifier}-{version}-{url}",
+                grant=StaticGrant(token=token, discovery=StaticDiscovery(base_url=url)),
+            )
+        ),
+        herre=Herre(
+            grant=HerreCacheGrant(
+                cache_file=f".arkitekt/cache/{identifier}-{version}_herre_cache.json",
+                hash=f"{identifier}-{version}-{url}",
+                grant=RefreshGrant(grant=FaktsGrant()),
+            ),
+        ),
+    )
+
 
 def qt(identifier: str, version: str, parent) -> Arkitekt:
     """
