@@ -81,6 +81,10 @@ def compile_scopes():
     return ["read", "write"]
 
 
+def compile_builders():
+
+    return ["arkitekt.builders.easy", "arkitekt.builders.port"]
+
 
 @click.group()
 @click.pass_context
@@ -93,7 +97,7 @@ def cli(ctx):
     pass
 
 @cli.command()
-@click.option('--builder', help='The builder used to construct the app', type=click.Choice(["arkitekt.builders.easy", "arkitekt.builders.advanced"]), default="arkitekt.builders.easy")
+@click.option('--builder', help='The builder used to construct the app', type=click.Choice(compile_builders()), default="arkitekt.builders.easy")
 def run(builder):
     """Runs the arkitekt app"""
     manifest = load_manifest()
@@ -104,7 +108,7 @@ def run(builder):
 
 
 @cli.command()
-@click.option('--builder', help='The builder used to construct the app', type=click.Choice(["arkitekt.builders.easy", "arkitekt.builders.advanced"]), default="arkitekt.builders.easy")
+@click.option('--builder', help='The builder used to construct the app', type=click.Choice(compile_builders()), default="arkitekt.builders.easy")
 def dev(builder):
     """Runs the arkitekt app"""
     manifest = load_manifest()
@@ -202,7 +206,7 @@ def port(version, dockerfile, nopush, tag):
 
     deployed["docker"] = tag
 
-    generate_deployment(identifier, version, entrypoint, deployed, deployer="arkitekt.deployers.port.dockerbuild")
+    generate_deployment(identifier, version, entrypoint, deployed, "arkitekt.deployers.port.dockerbuild", manifest.scopes)
 
 
 def prompt_scopes():
